pub struct PackInstallProgress {
pub received_bytes: u64,
pub indexed_objects: u64,
pub total_objects: u64,
}Expand description
Monotonic receipt and indexing counters for one staged pack installation.
Fields
received_bytes: u64Pack bytes received from the input so far.
indexed_objects: u64Objects fully inflated, resolved, and hashed so far.
total_objects: u64Total objects declared by the pack header once it is available.